<?php
/*
Plugin Name:  LW-Events
Plugin URI:   https://www.limaweb.nl/downloads/
Description:  LW-Events is a simple and user-friendly WordPress plugin designed to create and manage simple events on your website. With its intuitive interface and seamless integration, organizing and promoting events has never been easier. And to make it even more convenient, we've also included an Elementor widget for seamless event integration into your pages. Say goodbye to complex event management and hello to LW-Events!
Version:      1.0
Author:       LimaWeb
Author URI:   https://www.limaweb.nl/
License:      GPL2
License URI:  https://www.gnu.org/licenses/gpl-2.0.html
*/


// Add css file to front-end
function lw_events_enqueue_styles()
{
    wp_register_style('lw-events', plugins_url('style.css', __FILE__));
    wp_style_add_data('lw-events', 'preload', 'all');
    wp_enqueue_style('lw-events');
}
add_action('wp_enqueue_scripts', 'lw_events_enqueue_styles');

// Register custom post type
function lw_create_post_type()
{
    // Set up labels
    $labels = array(
        'name' => 'Events',
        'singular_name' => 'Event',
        'add_new' => 'Add New Event',
        'add_new_item' => 'Add New Event',
        'edit_item' => 'Edit Event',
        'new_item' => 'New Event',
        'all_items' => 'All Events',
        'view_item' => 'View Event',
        'search_items' => 'Search Events',
        'not_found' => 'No Event Found',
        'not_found_in_trash' => 'No Event found in Trash',
        'parent_item_colon' => '',
        'menu_name' => 'Events',
    );

    // Register post type
    register_post_type('event', array(
        'labels' => $labels,
        'has_archive' => true,
        'public' => true,
        'supports' => array('title', 'editor', 'excerpt', 'custom-fields', 'thumbnail', 'page-attributes'),
        'taxonomies' => array('post_tag', 'category'),
        'exclude_from_search' => false,
        'capability_type' => 'post',
        'rewrite' => array('slug' => 'event'),
        'menu_icon' => 'dashicons-calendar', // Add Dashicon to custom post type menu. 
    ));

    // Register date meta field
    register_meta('event', 'date_meta', array(
        'type' => 'string',
        'description' => 'The date of the event',
        'single' => true,
        'show_in_rest' => true,
    ));
}
add_action('init', 'lw_create_post_type');

// Display the date meta field in the post editor
function lw_display_date_meta_field()
{
    global $post;

    // Get the stored date value
    $date_meta = get_post_meta($post->ID, 'date_meta', true);
?>
    <label for="date_meta">Date:</label>
    <input type="date" name="date_meta" id="date_meta" value="<?php echo esc_attr($date_meta); ?>">
<?php
}
add_action('edit_form_after_title', 'lw_display_date_meta_field');

// Save the date meta field value
function lw_save_date_meta_field($post_id)
{
    if (isset($_POST['date_meta'])) {
        update_post_meta($post_id, 'date_meta', sanitize_text_field($_POST['date_meta']));
    }
}
add_action('save_post', 'lw_save_date_meta_field');


if (!defined('ABSPATH')) exit; // Exit if accessed directly

final class Main_Elementor_Extension
{

    const VERSION = '1.0.0';
    const PLUGIN_SLUG = 'events-elementor-extension';

    private static $_instance = null;

    public static function instance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct()
    {
        add_action('elementor/widgets/widgets_registered', [$this, 'init_widgets']);
    }

    public function init_widgets()
    {
        // Include Widget files
        require_once(__DIR__ . '/event-widget.php');

        // Register widget
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new \Events_Elementor_Widget());
    }
}

Main_Elementor_Extension::instance();
